capturesdk library

This is main file for package

Classes

AppInfo
This is the app information used to access the API. These credentials are generated when you register your app on the Socket Mobile website.
Capture
The main entrypoint for Socket Mobile Capture SDK. Where connection to Capture library is initiated, maintained and through which requests are made.
CaptureEvent
Response from the capture library based on user interaction. When you use the scanner to scan a barcode, you will recieve a CaptureEvent of the decoded data.
CaptureEventIds
The different types of IDs used to differentiate different types of capture events.
CaptureEventTypes
CaptureException
Wraps any errors in a uniform class to ensure user only has to check for one data type and one set of properties.
CaptureProperty
Class for properties recieved/submitted in requests to Capture library. Capture properties can represent a device name, device type, monitor mode, etc.
CapturePropertyIds
Different types of property ids for different property types.
CapturePropertyTypes
Data types for different properties (ex: friendlyName is a string because when accessed from the device, it would read something like 'first friendly name').
CaptureVersion
What version of capture is being used.
DataSource
Where the event data stems from.
DataSourceIos
DecodedData
Data recieved from a device scan; response from device scan will be a capture event containing decoded data.
DeviceInfo
Basic properties for a paired or stored device.
HttpTransport
Main transport for establishing and making requests on Android. utilizing json rpc as well as Websockets to establish channel.
IosAppInfo
IosTransport
IosTransportAdaptor
iOS counterpart for HttpTransport. Given that iOS doesn't require HTTP and we leverage the existing iOS library we have a separate and unique transport builder for iOS.
IosTransportHandle
IosTransportNotification
Establishes event channel using StreamSubscription. Returns a capture event and establishes channel listener.
IosTransportResult
JRpcEvent
Wrapper for capture events when processed over http transport (Android).
JRpcRequest
Wrapper for HTTP request to use json rpc parameters. JRpcRequest is required for use with JsonRpc oriented transport.
JRpcResponse
Wrapper for response from http requests that utilize json rpc.
JsonRpc
Logger
Used to establish logging capability for developers. Optional to use but provides typified interface for custom logging and stack tracing.
Params
Used in requests as well as storing device or property details.
Property
SktErrors
defines the Errors used in Capture
Transport
Initial transport Interface. Here is where we check the operating system and determine which subclass transport to use (HttpTransport or IosTransport)
Version

Properties

defaultHost String
getter/setter pair

Functions

convertFromPlatformException(PlatformException exception, dynamic method, dynamic type) → dynamic
Converting a platform exception to a generic CaptureException.
propertySwitchStatement(dynamic prop, dynamic finalVal, dynamic isFromProperty) → dynamic
Helper for determining which property switch to use
toCapturePropertySwitch(dynamic prop, dynamic finalVal) → dynamic
Helper for determining which property should be assigned to the value (used in response) property.
toPropertySwitch(dynamic prop, dynamic finalVal) → dynamic
Helper for determining which property generic value (from response) should be assigned to.
typifyValue(dynamic val, dynamic type) → dynamic
Helper function to determine which type a dynamic value should be.