CaptureDeviceType class

Differentiate between types of devices (Model 7, NFC tag, etc).

Constructors

CaptureDeviceType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BtUnknown → const int
device type unknown by this version of Capture value: 196632 (0x30018)
DeviceManagerBle → const int
device manager for controlling BLE value: 17104897 (0x1050001)
NFCTag → const int
NFC Tag value: 393239 (0x60017)
None → const int
no device type (initial value) value: 0 (0x00000)
Scanner7 → const int
Model 7 value: 196609 (0x30001)
Scanner7x → const int
Model 7X value: 196610 (0x30002)
Scanner7xi → const int
Model 7Xi value: 196612 (0x30004)
Scanner9 → const int
Model 9 CRS value: 196611 (0x30003)
ScannerD600 → const int
Model D600 value: 327701 (0x50015)
ScannerD700 → const int
Model D700 value: 196617 (0x30009)
ScannerD730 → const int
Model D730 value: 196618 (0x3000A)
ScannerD740 → const int
Model D740 value: 196619 (0x3000B)
ScannerD750 → const int
Model D750 value: 196620 (0x3000C)
ScannerD760 → const int
Model D760 value: 196621 (0x3000D)
ScannerD790 → const int
Model D790 value: 196628 (0x30014)
ScannerS550 → const int
Model S550 value: 327702 (0x50016)
ScannerS700 → const int
Model S700 value: 196622 (0x3000E)
ScannerS730 → const int
Model S730 value: 196623 (0x3000F)
ScannerS740 → const int
Model S740 value: 196624 (0x30010)
ScannerS750 → const int
Model S750 value: 196625 (0x30011)
ScannerS760 → const int
Model S760 value: 196626 (0x30012)
ScannerS800 → const int
Model S800 value: 196614 (0x30006)
ScannerS840 → const int
Model S840 value: 196616 (0x30008)
ScannerS850 → const int
Model S850 value: 196615 (0x30007)
ScannerS860 → const int
Model S860 value: 196627 (0x30013)
SocketCam → const int
SocketCam (only used in iOS and Android) value: 5 (0x00005)