CapturePropertyTypes class

Constructors

CapturePropertyTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

array → const int
the property has a byte array value
byte → const int
the property has a byte value
dataSource → const int
the property has a data source structure as value
Enum → const int
the property has an enum value
lastType → const int
the property type should not be equal or higher that kLast otherwise it means the SDK is not in sync with the actual version of Socket Mobile Companion running on the host
none → const int
for capture properties that don't have any value
notApplicable → const int
for capture properties that don't have a value for either a get operation or a set operation or neither of them.
object → const int
the property has an object as value
string → const int
the property has a string value
ulong → const int
the property has a unsigned long value
version → const int
the property has a version structure as value (read only)