RumbleActionType class
Rumble configuration for the a type of action
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- badRead → const int
- Rumble configuration for a bad read action
- badReadLocal → const int
- Rumble configuration for a bad read local action
- goodRead → const int
- Rumble configuration for a good read action
- goodReadLocal → const int
- Rumble configuration for a good read local action