CapturePropertyIds class
Different types of property ids for different property types.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- abort → const int
- applyConfigDevice → const int
- batteryLevelDevice → const int
- bluetoothAddressDevice → const int
- capabilitiesDevice → const int
- changeIdDevice → const int
- configuration → const int
- connectionBeepConfigDevice → const int
- connectReasonDevice → const int
- dataConfirmationAction → const int
- dataConfirmationDevice → const int
- dataConfirmationMode → const int
- dataFormatDevice → const int
- dataSourceDevice → const int
- dataStoreDevice → const int
- deletePairingBondingDevice → const int
- deviceSpecific → const int
- deviceType → const int
- disconnectDevice → const int
- favorite → const int
- flashDevice → const int
- friendlyNameDevice → const int
- interfaceVersion → const int
- localAcknowledgmentDevice → const int
- localDecodeActionDevice → const int
- monitorMode → const int
- notificationsDevice → const int
- overlayViewDevice → const int
- pcScCouplerControl → const int
- pcScTagTransmit → const int
- pinCodeDevice → const int
- postambleDevice → const int
- powerStateDevice → const int
- preambleDevice → const int
- profileConfigDevice → const int
- restoreFactoryDefaultsDevice → const int
- rumbleConfigDevice → const int
- securityModeDevice → const int
- setPowerOffDevice → const int
- softScanStatus → const int
- soundConfigDevice → const int
- standConfigDevice → const int
- startDiscovery → const int
- startUpRoleSPPDevice → const int
- statisticCountersDevice → const int
- timersDevice → const int
- triggerDevice → const int
- uniqueDeviceIdentifier → const int
- version → const int
- versionDevice → const int