CapturePropertyTypes class

Data types for different properties (ex: friendlyName is a string because when accessed from the device, it would read something like 'first friendly name').

Constructors

CapturePropertyTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

array → const int
byte → const int
dataSource → const int
Enum → const int
lastType → const int
none → const int
notApplicable → const int
object → const int
string → const int
ulong → const int
version → const int