CaptureDeviceTypeClass class
Differentiate between devices and device managers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- DeviceClass → const int
- the class is a device value: 0 (0x00000)
- DeviceManagerClass → const int
- the class is a device manager value: 1 (0x00001)