CaptureDeviceTypeInterface class
Differentiate between types of interfaces (bluetooth, NFC, etc).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- Ble → const int
- Bluetooth Low Energy interface value: 5 (0x00005)
- Bluetooth → const int
- Bluetooth interface value: 3 (0x00003)
- CF → const int
- CF interface value: 2 (0x00002)
- NFC → const int
- NFC value: 6 (0x00006)
- None → const int
- no interface value: 0 (0x00000)
- SD → const int
- SD interface value: 1 (0x00001)
- Serial → const int
- Serial interface value: 4 (0x00004)