CaptureEventTypes class
Types of Capture Events a user might encounter.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- array → const int
- The event has a byte array value.
- byte → const int
- The event has a byte value.
- decodedData → const int
- The event has a decoded data structure as value.
- deviceInfo → const int
- The event has a device info structure as value (read only).
- lastID → const int
- The event type should not be equal or higher that kLastID otherwise it means the SDK is not in sync with the actual version of Socket Mobile Companion running on the host.
- none → const int
- For capture events that don't have any value.
- string → const int
- The event has a string value.
- ulong → const int
- The event has a unsigned long value.